/*#############################################################
File Name       : ex1_LSM303DLHC_heading_roll_pitch_swv.c
Author          : Grant Phillips
Date Modified   : 07/05/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F3-Discovery

Description     : Example program that demonstrates the use
									of the LSM303DLHC 3D Accelerometer and 
									Magnetometer module found on the STM32F3-
									Discovery board.  The heading (compass), 
									roll, and pitch angles will be displayed as 
									float values.   

									The output is displayed on a PC using the
									Serial Wire Viewer (SWV).  See the SWV examples
									for an explanation of the use of this feature.

Requirements    : * STM32F3-Discovery Board
									* Make sure the LSM303DLHC_F3.c file is in the 
                    same folder than the project
              
Circuit         : * A wire link between PB3 and pin6 of the SWD
										connector (CN3) as explained in the SWV
										examples section
									
See the STM32F3-Discovery User Manual (UM1570) for the block 
diagram of the STM32F303VCT6 processor (p13), a summary of
the GPIO connections (p21-29) and the schematic diagram (p31-34)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.
#include "LSM303DLHC_F3.c"																			//for the LSM303DLHC 3D Accelerometer and Magnetometer

/* #defines --------------------------------------------------*/
		
/* #function prototypes --------------------------------------*/

/* #global variables -----------------------------------------*/
GPIO_InitTypeDef        GPIO_InitStructure;											//structure used for setting up a GPIO port
RCC_ClocksTypeDef 			RCC_Clocks;															//structure used for setting up the SysTick Interrupt



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	float Heading, Roll, Pitch;																		//float variables to hold values for the heading, roll and pitch angles

	
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	printf("Hallo\n");
	LSM303DLHC_Init();																						//initialize the LSM303DLHC module
	printf("Bye\n");
	/* Main program loop */
  while (1)
  {
		
    /* Read LSM303DLHC values */
    LSM303DLHC_ReadValues(&Heading, &Roll, &Pitch);
		printf("XXXX\n");
		
		/* Display values */
		if ((Roll <= 30.0f) && (Pitch <= 30.0f))										//heading is only accurate if board is level
		{
			printf("R: %11.3f   P: %11.3f   H: %11.3f\n", Roll, Pitch, Heading);	
		}
		else																												//don't display heading value when board is not level
		{
			printf("R: %11.3f   P: %11.3f   H: ***********\n", Roll, Pitch);	
		}

    Delay(250);																									//delay of at least 5ms for reading values from LSM303DLHC module
  }	
}


/*
Retarget the C library printf function to the SWO Viewer.
Overwrites int fputc(int ch, FILE *f) function used by printf.
*/								
int fputc(int ch, FILE *f)
{
	return(ITM_SendChar(ch));
}







// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



