/*#############################################################
File Name       : ex1_ROB-09454_swv.c
Author          : Grant Phillips
Date Modified   : 15/10/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F3-Discovery

Description     : Example program that demonstrates the use
									of the ROB-09454 Digital Line Sensor 
									(https://www.sparkfun.com/products/9454)

									The output is displayed on a PC using the
									Serial Wire Viewer (SWV).  See the SWV examples
									for an explanation of the use of this feature.
									
Requirements    : * STM32F3-Discovery Board
              
Circuit         : * The ROB-09454 Digital Line Sensor is connected 
										as follows:
										OUT										-	PC0
										VCC										-	3V
										GND										-	GND
									* A wire link between PB3 and pin6 of the SWD
										connector (CN3) as explained in the SWV
										examples section
									
See the STM32F3-Discovery User Manual (UM1570) for the block 
diagram of the STM32F303VCT6 processor (p13), a summary of
the GPIO connections (p21-29) and the schematic diagram (p31-34)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/
uint16_t ROB09454_ReadPulse(void);															//prototype for the user function to read the line sensor

/* #global variables -----------------------------------------*/
RCC_ClocksTypeDef 			RCC_Clocks;															//structure used for setting up the SysTick Interrupt


// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	uint16_t pulse;            																		//variable for the line sensor result

	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
					
	/* Main program loop */
  while (1)
  {
		pulse = ROB09454_ReadPulse();					//get the line sensor value
		
		printf("%d\n" , pulse); 
		
    Delay(10);														//a delay to just prevent the line sensor from being re-triggered to quickly 
																					//by allowing the cap to discharge sufficiently.  Keep the
																					//delay between triggers above 10ms.
  }	
}


	
/*
Retarget the C library printf function to the SWO Viewer.
Overwrites int fputc(int ch, FILE *f) function used by printf.
*/								
int fputc(int ch, FILE *f)
{
	return(ITM_SendChar(ch));
}



/* This function will pulse the Out pin of the sensor
for 10us which charges an internal capacitor.  The Out pin
is then changed to an input.  We then monitor this input
and increment a counter while the capacitor's charge is
high.  The value returned by the function is will be a low
value for a white surface and a high value for a dark surface.
The maximum value returned is set to 32000.
This example uses PC0 for the Out pin, but can be changed to 
any other pin.  If more than 1 line sensor is used, this 
function can just be duplicated using other pins */
uint16_t ROB09454_ReadPulse(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;				//structure used for setting up a GPIO port
  uint16_t counter;            											//counter variable to determine the HIGH pulse
	uint16_t i;

	/* GPIOC Periph clock enable */
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOC, ENABLE);		//enable the AHB bus to use GPIOC
	
  /* Configure PC0 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;									
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;								
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;							
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							
  GPIO_Init(GPIOC, &GPIO_InitStructure);						//PC0 is now an output; Sig pin
	       
	/* create a 10us HIGH pulse on Out pin */
	GPIO_SetBits(GPIOC, GPIO_Pin_0);									//PC0 = 1	
	for(i=0;i<=70;i++)
	{};				//do nothing
  GPIO_ResetBits(GPIOC, GPIO_Pin_0);								//PC0 = 0	

	/* Configure PC0 in input mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;														
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;							
  GPIO_Init(GPIOC, &GPIO_InitStructure);						//PC0 is now an input; Sig pin
		
  counter=0;                     																	//reset the counter
  while(GPIO_ReadInputDataBit(GPIOC, GPIO_Pin_0)==1)            	//increment a counter while the Out pulse is HIGH
  {
    counter++;
		if (counter>=32000)															//max value is 32000 to prevent too long delays
			break;
  }
  return(counter);
}





// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



